# See LICENSE file for full copyright and licensing details.

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError, UserError


class ResConfig(models.TransientModel):
    _inherit = 'res.config.settings'

    dropbox_key = fields.Char('DropBox Auth Token')

    @api.model
    def get_values(self):
        res = super(ResConfig, self).get_values()
        dropbox_key = self.env['ir.config_parameter'].get_param(
            'dropbox_key') or ''
        res.update({'dropbox_key': dropbox_key})
        return res

    @api.multi
    def set_values(self):
        super(ResConfig, self).set_values()
        for rec in self:
            self.env['ir.config_parameter'].set_param(
                'dropbox_key', rec.dropbox_key)

    def testDropbox(self):
        dpx = self.dropboxConnection()
        if not dpx:
            raise ValidationError(
                _('Something Went wrong with Connection with Dropbox'))
        raise UserError(_('Test Successful'))

    @api.model
    def dropboxConnection(self):
        dropbox_key = self.env['ir.config_parameter'].get_param(
            'dropbox_key') or ''
        dpx = self.env['utils.utils'].connection(dropbox_key)
        return dpx

    def fetchDropboxFolders(self):
        dpx = self.dropboxConnection()
        folder_list = self.env['utils.utils'].folderList(dpx, True)
        box_pool = self.env['drop.box.folder']
        if folder_list:
            for entry in folder_list:
                sr_ids = box_pool.search([('dropbox_id', '=', entry.id)])
                if not sr_ids:
                    box_pool.create({
                        'name': entry.name,
                        'path': entry.path_display,
                        'dropbox_id': entry.id})
                else:
                    sr_ids.write({
                        'name': entry.name,
                        'path': entry.path_display})
